#
# spec file for package archivemail
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}

Name:           archivemail
Version:        0.9.0
Release:        13.5
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Url:            http://archivemail.sf.net/
Source:         http://downloads.sourceforge.net/project/%{name}/%{name}/%{version}/%{name}-%{version}.tar.gz
Summary:        Tool for Archiving and Compressing Old Email in Mailboxes
License:        GPL-2.0+
Group:          Productivity/Networking/Email/Utilities
BuildRequires:  ed
BuildRequires:  python-devel
%{py_requires}
%if %{?suse_version: %{suse_version} > 1110} %{!?suse_version:1}
BuildArch:      noarch
%endif

%description
archivemail is a tool for archiving and compressing old email in mailboxes. It
moves messages older than the specified number of days to a separate mbox
format mailbox that is compressed with gzip. It can also just delete old email
rather than archive it.

%prep
%setup -q
ed -s examples/archivemail_all 2>/dev/null <<'EOF'
,s/\/usr\/local\/bin\/archivemail/\/usr\/bin\/archivemail/
w
EOF

%build
%{__python} setup.py build

%install
# python => 2.5 expects this to exist (it will exist if the package
# installs something there, but we don't)
mkdir -p $RPM_BUILD_ROOT/%{python_sitelib}
%{__python} setup.py install --prefix=%{_prefix} --root %{buildroot}
# we don't need the egg file which python => 2.5 installs
rm -f $RPM_BUILD_ROOT/%{python_sitelib}/*

%files
%defattr(-,root,root)
%{_bindir}/archivemail
%doc %{_mandir}/man1/archivemail.1*
%doc CHANGELOG examples/* FAQ README TODO

%changelog
* Wed May 16 2012 gber@opensuse.org
- update to version 0.9.0
  * IMAP: support for international mailbox names containing
    non-ASCII characters
- dropped obsolete archivemail-0.7.2-fix-paths.patch
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Fri Apr  1 2011 gber@opensuse.org
- update to version 0.8.2
  * bugfixes
* Fri Aug 20 2010 gber@opensuse.org
- update to version 0.8.0
  * new option --debug-imap to dump the IMAP conversation to stdout
  * new option --all to archive all messages in a mailbox
  * new option --prefix/-p, to specify an archive name prefix
  * new option --archive-name/-a to hard-code an archive filename
  * archivemail now expands wildcards in IMAP mailbox names
  * many bugfixes
- dropped archivemail-0.7.2-fix-unnecessary-assertions.patch
- changed group to something more appropriate
* Wed Jan 20 2010 guido+opensuse.org@berhoerster.name
- cleanup
- build as noarch for opensuse > 11.1
- backported two fixes resulting in exceptions when archiving empty maildirs
  or with --days=0
* Fri Nov  9 2007 poeml@suse.de
- update to 0.7.2
  * fix crash with Python << 2.5, introduced with 0.7.1
* Fri Nov  9 2007 poeml@suse.de
- update to 0.7.1
  * Fixed incompatibility with Python 2.5 which broke Maildir handling.
  * Fixed IMAP message flag conversion which was completely broken.
  * Username and password in IMAP URLs can now be double-quoted, so it should be
    no longer a problem if they contain delimiters like the '@' character.
  * New option --copy: archive mail, but don't delete it from the mailbox.
    This is mainly useful for testing purposes, and complements --delete.
  * IMAP: if selecting the mailbox fails, archivemail detects the server's
    mailbox hierarchy delimiter, replaces slashes in the mailbox name with the
    delimiter and tries again.
  * When converting from other formats to mbox, archivemail used to preserve
    existing 'Status' and 'X-Status' mbox headers; these are now silently
    overwritten to ensure they have correct values.
  * Invalid messages/files in Maildirs caused archivemail to silently stop
    processing mails and claim it's all done.  Now skip these and go ahead.
  * The automatic seteuid feature of archivemail is insecure and thus
    deprecated; it will be removed from later versions.
  * archivemail now accepts --days=0
* Fri Nov  3 2006 poeml@suse.de
- update to 0.7.0 (bug numbers below are in the sf.net tracker
  unless indicated otherwise)
  * Fixed long options --filter-append and --pwfile to accept their arguments.
    Closes: #1555935
  * Fixed From_ line generation to actually look for the 'Return-path' and
    'From' headers.  Closes: #1555797
  * Fixed IMAP authentication/URL parsing, which wasn't working at all in
    v0.6.2.  Require username encoded in URL, but be flexible with the password:
    handle both --pwfile and URL-encoded password, and fallback to querying the
    user if neither is present.  Closes: #1555951
  * Convert on-the-wire CRLF to native EOL when saving messages from an IMAP
    folder.  Closes: #1555803
  * Updated man page.  This also addresses #1555951
  * Fixed unittest failure by updating --suffix testcase.  Based on analysis by
    Peter Poeml.  Thanks, Peter.
  * Fixed invalid IMAP filter string for large messages (--size option).
    (Thanks to the anonymous bug reporter)  Closes: #863813
  * Fixed IMAP --dry-run so it doesn't download all messages that would be
    archived.
  * Fixed IMAP --delete which didn't work at all.  (Thanks Anand)
    Closes: Debian bug #203282
  * Terminate each message in newly written mbox with an empty line if the
    message source is not an mbox-format folder.  (Thanks  Chung-chieh Shan)
    Closes: Debian bug #250410
  * Mangle From_ in message body if the message source is not an mbox-format
    folder.  (Thanks Chung-chieh Shan)  Closes: Debian bug #250402
  * Added new option --dont-mangle to turn off From_ mangling.
  * Bumped Python dependency to version 2.3.
  * Fixed unittest TestMboxExclusiveLock which failed on Solaris.  (Thanks Paul
    Rodger)  Closes: #904652
  * Fixed unsafe creation of temporary files in the test suite.
    This addresses Debian bug #385253, and reading the BTS log, it seems this
    issue was assigned CVE-2006-4245, although I cannot find any further
    reference to that CVE.  Note that the bug was initially reported to affect
    archivemail itself, too.  This is not correct.  (Thanks Joey Hess)
    Closes: Debian bug #385253
  * Fixed cleanup of temporary files after test suite failures.
  * Fixed dotlocking race condition.
  * Stats are now working with IMAP.
  * Stats now report the total size of a mailbox and of the archived messages
    therefrom.
  * Always barf if the archive destination directory is world-writable.
  * Distributing man page with the tarball again and fixed distutils setup.
    Closes: #1574720 (Thanks Grant Goodyear)
  * Improved IMAP error reporting
* Fri Sep 29 2006 poeml@suse.de
- fix build with python 2.5
* Mon Jun 26 2006 poeml@suse.de
- new package (0.6.2)
  * add -F/--filter-append option to append an arbitrary string to the IMAP
    filter string
  * don't delete more than a certain number of messages at a time. The max
    command len is limited. Fixes bug 942403 (Archiving large IMAP folders fails)
  * add SSL support per imaps URL (after patch by Tobias Gruetzmacher)
  * add -P/--pwfile option to supply the IMAP password, so it does not end up in
    the shell history
  * Fix SyntaxWarning: assignment to None (bug #843890)
  * Use the archive cut date rather than the actual time with the --suffix
    option. (Thanks Manuel Estrada Sainz)
